import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:minehunter/config/default_game_settings.dart';
import 'package:minehunter/models/settings/settings_game.dart';

part 'settings_game_state.dart';

class GameSettingsCubit extends HydratedCubit<GameSettingsState> {
  GameSettingsCubit() : super(GameSettingsState(settings: GameSettings.createDefault()));

  void setValues({
    String? itemsCount,
    String? timerValue,
  }) {
    emit(
      GameSettingsState(
        settings: GameSettings(
          level: itemsCount ?? state.settings.level,
          size: timerValue ?? state.settings.size,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultGameSettings.parameterCodeLevel:
        return GameSettings.getLevelValueFromUnsafe(state.settings.level);
      case DefaultGameSettings.parameterCodeSize:
        return GameSettings.getSizeValueFromUnsafe(state.settings.size);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String itemsCount = code == DefaultGameSettings.parameterCodeLevel
        ? value
        : getParameterValue(DefaultGameSettings.parameterCodeLevel);
    final String timerValue = code == DefaultGameSettings.parameterCodeSize
        ? value
        : getParameterValue(DefaultGameSettings.parameterCodeSize);

    setValues(
      itemsCount: itemsCount,
      timerValue: timerValue,
    );
  }

  @override
  GameSettingsState? fromJson(Map<String, dynamic> json) {
    final String itemsCount = json[DefaultGameSettings.parameterCodeLevel] as String;
    final String timerValue = json[DefaultGameSettings.parameterCodeSize] as String;

    return GameSettingsState(
      settings: GameSettings(
        level: itemsCount,
        size: timerValue,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(GameSettingsState state) {
    return <String, dynamic>{
      DefaultGameSettings.parameterCodeLevel: state.settings.level,
      DefaultGameSettings.parameterCodeSize: state.settings.size,
    };
  }
}
